package middleware

import (
	"context"
	"log/slog"
	"net/http"

	"github.com/gofrs/uuid/v5"
)

type contextKey string
const TraceIdKey contextKey = "trace_id"

func ContextMiddleware(logger *slog.Logger) func(http.Handler) http.Handler {
	return func(next http.Handler) http.Handler {
		return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
			traceid, err := uuid.NewV4()
			if err != nil {
				logger.ErrorContext(r.Context(), err.Error())
			}
			ctx := context.WithValue(r.Context(), TraceIdKey, traceid)
			newReq := r.WithContext(ctx)

			next.ServeHTTP(w, newReq)
		})
	}
}
